<?php

// main Revolution Multimedia Gallery Wordpress Plugin plugin class
class FWDRMG
{
	// constants
	const MIN_WP_VER =  "3.5.0";
	const CAPABILITY = "edit_fwdrmg";
	const VERSION = "1.0";
	
	// variables
	private $_data;
	private $_dir_url;
    
    private static $_rmg_id = 0;
    
    // constructor
    public function init()
    {
		$this->_dir_url = plugin_dir_url(dirname(__FILE__));
		
		// set data
		$this->_data = new FWDRMGData();		
		$this->_data->init();
		
    	// set hooks
    	add_action("admin_menu", array($this, "add_plugin_menu"));
		add_action("wp_enqueue_scripts", array($this, "add_header_files"));
		add_shortcode("fwdrmg", array($this, "set_rmgerflow"));
    }

    // functions
    public function add_plugin_menu()
    {
    	// add menus
        add_menu_page("Gallery Title", "Revolution Multimedia Gallery", FWDRMG::CAPABILITY, "FWDRMGMenu-General-Settings", array($this, "set_general_settings"), $this->_dir_url . "load/icons/menu-icon.png");
       	add_submenu_page("FWDRMGMenu-General-Settings", "General settings", "General settings", FWDRMG::CAPABILITY, "FWDRMGMenu-General-Settings");
       	add_submenu_page("FWDRMGMenu-General-Settings", "Playlists manager", "Playlists manager", FWDRMG::CAPABILITY, "FWDRMGMenu-Playlists-Manager", array($this, "set_playlists_manager"));
       	add_submenu_page("FWDRMGMenu-General-Settings", "CSS Editor", "CSS Editor", FWDRMG::CAPABILITY, "FWDRMGMenu-CSS-Editor", array($this, "set_css_editor"));
       	
       	// add meta boxes
       	$post_type_screens = array("post", "page");

    	foreach ($post_type_screens as $screen)
    	{
       		add_meta_box("fwdrmg-shortcode-generator", "FWDRMG Shortcode Generator",  array($this, "set_custom_meta_box"), $screen, "side", "default");
    	}
    }
    
	private function check_wp_ver()
	{
	    global $wp_version;
	    
		$exit_msg = "The Revolution Multimedia Gallery requires WordPress " . FWDRMG::MIN_WP_VER . " or newer. <a href='http://codex.wordpress.org/Updating_WordPress'>Please update!</a>";
		
		if (version_compare($wp_version, FWDRMG::MIN_WP_VER) <= 0)
		{
			echo $exit_msg;
			
			return false;
		}
		
		return true;
	}

    public function set_general_settings()
    {
    	if (!$this->check_wp_ver())
    	{
    		return;
    	}
    	
    	$msg = "";
    	
    	$set_id = 0;
		$set_order_id = 0;
		$tab_init_id = 0;
    	
	    if (!empty($_POST) && check_admin_referer("fwdrmg_general_settings_update", "fwdrmg_general_settings_nonce"))
		{
			$data_obj = json_decode(str_replace("\\", "", $_POST["settings_data"]), true);
			
			$action = $data_obj["action"];
			$settingsAr = $data_obj["settings_ar"];
			
			$this->_data->settings_ar = $settingsAr;
			$this->_data->set_data();
			
			switch ($action)
			{
			    case "add":
			        $msg = "<div class='fwd-updated'><p style='padding:8px;'>Your new preset has been added!</p></div>";
			        $set_id = $data_obj["set_id"];
					$set_order_id = $data_obj["set_order_id"];
					$tab_init_id = $data_obj["tab_init_id"];
			        break;
			    case "save":
			        $msg = "<div class='fwd-updated'><p style='padding:8px;'>Your preset settings have been updated!</p></div>";
			        $set_id = $data_obj["set_id"];
					$set_order_id = $data_obj["set_order_id"];
					$tab_init_id = $data_obj["tab_init_id"];
			        break;
			    case "del":
			       	$msg = "<div class='fwd-updated'><p style='padding:8px;'>Your preset has been deleted!</p></div>";
			        break;
			}
		}
		
		// jquery ui
		wp_enqueue_style("fwdrmg_fwd_ui_css", $this->_dir_url . "css/fwd_ui.css");
		wp_enqueue_script("jquery-ui-tabs");
		wp_enqueue_script("jquery-ui-sortable");
		wp_enqueue_script("jquery-ui-accordion");
		wp_enqueue_script("jquery-ui-tooltip");
		
		// spectrum colorpicker
    	wp_enqueue_style("fwdrmg_spectrum_css", $this->_dir_url . "css/spectrum.css");
    	wp_enqueue_script("fwdrmg_spectrum_script", $this->_dir_url . "js/spectrum.js");
    	
    	// general settings script
		wp_enqueue_media();
        wp_enqueue_script("fwdrmg_general_settings_script", $this->_dir_url . "js/general_settings.js");
		
    	include_once "general_settings.php";
    }
    
 	public function set_playlists_manager()
    {
    	if (!$this->check_wp_ver())
    	{
    		return;
    	}
    	
    	$msg = "";
    	
	    if (!empty($_POST) && check_admin_referer("fwdrmg_playlist_manager_update", "fwdrmg_playlist_manager_nonce"))
		{
			$playlistsAr = json_decode(str_replace("\\", "", $_POST["playlist_data"]), true);
			
			$this->_data->playlists_ar = $playlistsAr;
			$this->_data->set_data();
			
			$msg = "<div class='fwd-updated'><p style='padding:8px;'>Your playlists have been updated!</p></div>";
		}
		
		// jquery ui
		wp_enqueue_style("fwdrmg_fwd_ui_css", $this->_dir_url . "css/fwd_ui.css");
		wp_enqueue_script("jquery-ui-tabs");
		wp_enqueue_script("jquery-ui-sortable");
		wp_enqueue_script("jquery-ui-accordion");
		wp_enqueue_script("jquery-ui-dialog");
		wp_enqueue_script("jquery-ui-tooltip");
		
		// playlist manager script
		wp_enqueue_media();
        wp_enqueue_script("fwdrmg_playlist_manager_script", $this->_dir_url . "js/playlist_manager.js");
        
    	include_once "playlist_manager.php";
    }
    
    public function set_css_editor()
    {
    	if (!$this->check_wp_ver())
    	{
    		return;
    	}
    	
    	$msg = "";
    	$scroll_pos = 0;
    	
    	$css_file = plugin_dir_path(dirname(__FILE__)) . "css/fwdrmg.css";
    	
	    if (!empty($_POST) && check_admin_referer("fwdrmg_css_editor_update", "fwdrmg_css_editor_nonce"))
		{
			$handle = fopen($css_file, "w") or die("Cannot open file: " . $css_file);
			
			$data = $_POST["css_data"];
			$scroll_pos = $_POST["scroll_pos"];
			
			fwrite($handle, $data);
			
			$msg = "<div class='fwd-updated'><p style='padding:8px;'>The CSS file has been updated!</p></div>";
		}
		
		wp_enqueue_style("fwdrmg_fwd_ui_css", $this->_dir_url . "css/fwd_ui.css");
	  			
		$handle = fopen($css_file, "r") or die("Cannot open file: " . $css_file);
        
    	include_once "css_editor.php";
    	
    	fclose($handle);
    }
    
	public static function set_action_links($links)
	{
		$settings_link = "<a href='" . get_admin_url(null, "admin.php?page=FWDRMGMenu-General-Settings") . "'>Settings</a>";
   		array_unshift($links, $settings_link);
   		
   		return $links;
	}
	
 	public function add_header_files()
    {
    	wp_enqueue_style("fwdrmg_rmg_css", $this->_dir_url . "css/fwdrmg.css");
    	wp_enqueue_script("fwdrmg_rmg_script", $this->_dir_url . "js/FWDRMG.js");
    }
    
    public function get_constructor($sid, $pid)
    {
    	$preset = NULL;
    	
    	foreach ($this->_data->settings_ar as $set)
    	{
    		if ($set["name"] == $sid)
    		{
    			$preset = $set;
    		}
    	}
    	
    	if (is_null($preset))
    	{
    		return "Preset with id ". $sid . " does not exist!";
    	}
    	
    	$playlist = NULL;
    	
    	foreach ($this->_data->playlists_ar as $pl)
    	{
    		if ($pl["name"] == $pid)
    		{
    			$playlist = $pl;
    		}
    	}
    	 	
    	if (is_null($playlist))
    	{
    		return "Playlist with id ". $pid . " does not exist!";
    	}
    	
    	return "<script type='text/javascript'>document.addEventListener('DOMContentLoaded', function(event) {FWDRMGUtils.checkIfHasTransofrms();window.fwdrmg" . FWDRMG::$_rmg_id. " = new FWDRMG({" . "parentId:'fwdrmgDiv" . FWDRMG::$_rmg_id. "',instanceName:'fwdrmg" . FWDRMG::$_rmg_id . "',playlistId:'fwdrmgPlaylist" . $pid . "', skinPath:'" . $preset['skin_path'] . "', mainFolderPath:'" . $this->_dir_url . "load'," ."displayType:'" . $preset['display_type'] . "',rightClickContextMenu:'" . $preset['rightClickContextMenu'] . "',buttonsAlignment:'" . $preset['buttonsAlignment'] . "',allCategoriesLabel:'" . $preset['allCategoriesLabel'] . "',zindex:" . $preset['zindex'] . ",useDeepLinking:'" . $preset['useDeepLinking'] . "',autoScale:'" . $preset['autoscale'] . "',showAllCategories:'" . $preset['showAllCategories'] . "',randomizeAllCategories:'" . $preset['randomizeAllCategories'] . "',randomizeCategories:'" . $preset['randomizeCategories'] . "',slideShowAutoPlay:'" . $preset['slideShowAutoPlay'] . "',addKeyboardSupport:'" . $preset['addKeyboardSupport'] . "',showFullScreenButton:'" . $preset['showFullScreenButton'] . "',showFacebookButton:'" . $preset['showFacebookButton'] . "',showZoomButton:'" . $preset['showZoomButton'] . "',showSlideShowButton:'" . $preset['showSlideShowButton'] . "',showSlideShowAnimation:'" . $preset['showSlideShowAnimation'] . "',showNextAndPrevButtons:'" . $preset['showNextAndPrevButtons'] . "',showNextAndPrevButtonsOnMobile:'" . $preset['showNextAndPrevButtonsOnMobile'] . "',maxWidth:" . $preset['maxwidth'] . ",maxHeight:" . $preset['maxheight'] . ",startAtItem:" . $preset['startAtItem'] . ",buttonsHideDelay:" . $preset['buttonsHideDelay'] . ",slideShowDelay:" . $preset['slideShowDelay'] . ",defaultItemWidth:" . $preset['defaultItemWidth'] . ",defaultItemHeight:" . $preset['defaultItemHeight'] . ",itemOffsetHeight:" . $preset['itemOffsetHeight'] . ",spaceBetweenButtons:" . $preset['spaceBetweenButtons'] . ",buttonsOffsetIn:" . $preset['buttonsOffsetIn'] . ",buttonsOffsetOut:" . $preset['buttonsOffsetOut'] . ",itemBorderSize:" . $preset['itemBorderSize'] . ",itemBorderRadius:" . $preset['itemBorderRadius'] . ",itemBoxShadow:'" . $preset['itemBoxShadow'] . "',itemBackgroundColor:'" . $preset['itemBackgroundColor'] . "',itemBorderColor:'" . $preset['itemBorderColor'] . "',backgroundColor:'" . $preset['backgroundColor'] . "'," .						"showThumbnails:'" . $preset['showThumbnails'] . "',showThumbnailsHideOrShowButton:'" . $preset['showThumbnailsHideOrShowButton'] . "',showThumbnailsByDefault:'" . $preset['showThumbnailsByDefault'] . "',showThumbnailsOverlay:'" . $preset['showThumbnailsOverlay'] . "',showThumbnailsSmallIcon:'" . $preset['showThumbnailsSmallIcon'] . "',thumbnailsHoverEffect:'" . $preset['thumbnailsHoverEffect'] . "',thumbnailsImageHeight:" . $preset['thumbnailsImageHeight'] . ",thumbnailsBorderSize:" . $preset['thumbnailsBorderSize'] . ",thumbnailsBorderRadius:" . $preset['thumbnailsBorderRadius'] . ",spaceBetweenThumbnailsAndItem:" . $preset['spaceBetweenThumbnailsAndItem'] . ",thumbnailsOffsetBottom:" . $preset['thumbnailsOffsetBottom'] . ",spaceBetweenThumbnails:" . $preset['spaceBetweenThumbnails'] . ",thumbnailsOverlayOpacity:" . $preset['thumbnailsOverlayOpacity'] . ",thumbnailsOverlayColor:'" . $preset['thumbnailsOverlayColor'] . "',thumbnailsBorderNormalColor:'" . $preset['thumbnailsBorderNormalColor'] . "',thumbnailsBorderSelectedColor:'" . $preset['thumbnailsBorderSelectedColor'] . "'," . 	"startAtCategory:" . ($preset['startAtCategory'] - 1) . ",showCategoriesMenuButton:'" . $preset['showCategoriesMenuButton'] . "',buttonBackgroundNormalColor:'" . $preset['buttonBackgroundNormalColor'] . "',buttonBackgroundSelectedColor:'" . $preset['buttonBackgroundSelectedColor'] . "',buttonTextNormalColor:'" . $preset['buttonTextNormalColor'] . "',buttonTextSelectedColor:'" . $preset['buttonTextSelectedColor'] . "',buttonBackgroundOpacity:" . $preset['buttonBackgroundOpacity'] . "," . "descriptionWindowPosition:'" . $preset['descriptionWindowPosition'] . "',showDescriptionButton:'" . $preset['showDescriptionButton'] . "',showDescriptionByDefault:'" . $preset['showDescriptionByDefault'] . "',descriptionWindowAnimationType:'" . $preset['descriptionWindowAnimationType'] . "',descriptionWindowBackgroundColor:'" . $preset['descriptionWindowBackgroundColor'] . "',descriptionWindowBackgroundOpacity:" . $preset['descriptionWindowBackgroundOpacity'] . "," . "useVideo:'" . $preset['useVideo'] . "',useAudio:'" . $preset['useAudio'] . "',videoShowFullScreenButton:'" . $preset['videoShowFullScreenButton'] . "',addVideoKeyboardSupport:'" . $preset['addVideoKeyboardSupport'] . "',nextVideoOrAudioAutoPlay:'" . $preset['nextVideoOrAudioAutoPlay'] . "',videoAutoPlay:'" . $preset['videoAutoPlay'] . "',videoLoop:'" . $preset['videoLoop'] . "',audioAutoPlay:'" . $preset['audioAutoPlay'] . "',audioLoop:'" . $preset['audioLoop'] . "',videoControllerHideDelay:" . $preset['videoControllerHideDelay'] . ",videoControllerHeight:" . $preset['videoControllerHeight'] . ",audioControllerHeight:" . $preset['audioControllerHeight'] . ",startSpaceBetweenButtons:" . $preset['startSpaceBetweenButtons'] . ",vdSpaceBetweenButtons:" . $preset['vdSpaceBetweenButtons'] . ",mainScrubberOffestTop:" . $preset['mainScrubberOffestTop'] . ",scrubbersOffsetWidth:" . $preset['scrubbersOffsetWidth'] . ",audioScrubbersOffestTotalWidth:" . $preset['audioScrubbersOffestTotalWidth'] . ",timeOffsetLeftWidth:" . $preset['timeOffsetLeftWidth'] . ",timeOffsetRightWidth:" . $preset['timeOffsetRightWidth'] . ",videoControllerBackgroundColor:'" . $preset['videoControllerBackgroundColor'] . "',videoPosterBackgroundColor:'" . $preset['videoPosterBackgroundColor'] . "',audioControllerBackgroundColor:'" . $preset['audioControllerBackgroundColor'] . "',timeColor:'" . $preset['timeColor'] . "'})});</script>";
    }
    
    public function get_playlist($pid)
    {
    	$playlist = NULL;
    	
    	foreach ($this->_data->playlists_ar as $pl)
    	{
    		if ($pl["name"] == $pid)
    		{
    			$playlist = $pl;
    		}
    	}
    	
    	if (is_null($playlist))
    	{
    		return "Playlist with id ". $pid . " does not exist!";
    	}
    	
    	$playlist_str = "<div id='fwdrmgPlaylist$pid' style='display: none;'>";
    	
    	foreach ($playlist["categories"] as $category)
    	{
    		$playlist_str .= "<ul data-category-name='" . $category["name"] . "'>";
    		
    		foreach ($category["thumbs"] as $thumb)
    		{
			
				$playlist_str .= "<li data-url='" . $thumb["url"] . "'";
					
				if(isset($thumb["path"]) && strlen($thumb["path"]) >= 1){
					$playlist_str .= " data-thumbnail-path='" . $thumb["path"] . "'";
				}
				
				if(isset($thumb["video_poster_source"]) && strlen($thumb["video_poster_source"]) >= 1){
					$playlist_str .= " data-poster-path='" . $thumb["video_poster_source"] . "'";
				}
				
				if(isset($thumb["item_max_width"]) && strlen($thumb["item_max_width"]) >= 1){
					$playlist_str .= " data-width='" . $thumb["item_max_width"] . "'";
				}
				
				if(isset($thumb["item_max_height"]) && strlen($thumb["item_max_height"]) >= 1){
					$playlist_str .= " data-height='" . $thumb["item_max_height"] . "'";
				}
				$playlist_str .= ">";
					
				if(isset($thumb["info"]) && strlen($thumb["info"]) >= 3){
					$playlist_str .= "<div>" . $thumb["info"] . "'</div>";
				}
				
			
				$playlist_str .= "</li>";
				 
    		}
    	
    		$playlist_str .= "</ul>";
    	}
    	
    	$playlist_str .= "</div>";
    	
    	return $playlist_str;
    }
    
 	public function set_rmgerflow($atts)
	{
		extract(shortcode_atts(array("preset_id" => 0, "playlist_id" => 0), $atts, "fwdrmg"));
		
		$cov_constructor = $this->get_constructor($preset_id, $playlist_id);
		$cov_div = "<div id='fwdrmgDiv" . FWDRMG::$_rmg_id. "'></div>";
		$cov_playlist = $this->get_playlist($playlist_id);
		
		FWDRMG::$_rmg_id++;
		
		$cov_output = $cov_constructor . $cov_div . $cov_playlist;
		
		return $cov_output;
	}
	
	public function set_custom_meta_box($post)
	{
		if (!$this->check_wp_ver())
    	{
    		return;
    	}
		
		// presets
		$presetsNames = array();
		
		foreach ($this->_data->settings_ar as $setting)
    	{
    		$el = array(
    						"id" => $setting["id"],
    						"name" => $setting["name"]
    				   );
    				   
    		array_push($presetsNames, $el);
    	}
    	
		// playlists
		$playlistsNames = array();
		
		if (isset($this->_data->playlists_ar))
		{
			foreach ($this->_data->playlists_ar as $playlist)
	    	{
	    		$el = array(
	    						"id" => $playlist["id"],
	    						"name" => $playlist["name"]
	    				   );
	    				   
	    		array_push($playlistsNames, $el);
	    	}
		}
		
    	wp_enqueue_style("fwdrmg_fwd_ui_css", $this->_dir_url . "css/fwd_ui.css");
		wp_enqueue_script("fwdrmg_shortcode_script", $this->_dir_url . "js/shortcode.js");
		
    	include_once "meta_box.php";
	}
}

?>